# Extract Sphinx RST Files

## Install
This installs the current stable version of xrst:

    pip install xrst

This installs the most recent version of xrst:

    pip install xrst
    pip uninstall -y xrst
    pip install --index-url https://test.pypi.org/simple/ xrst

## Purpose
https://xrst.readthedocs.io/latest/purpose.html

## Get Started
https://xrst.readthedocs.io/latest/get_started.html

## Git Repository
https://github.com/bradbell/xrst
